@@ -1175,3 +1175,100 @@ YAHOO.crud.toggle_link = function(id_to_toggle, link_id) {
     YAHOO.crud.toggle_class_hidden(link_id);
     return false;   // so the click is not followed on a href
 }
+
+YAHOO.crud.datetime_picker = function(id) {
+    YAHOO.crud.make_calendar_popup(id, true);
+}
+
+YAHOO.crud.date_picker = function(id) {
+    YAHOO.crud.make_calendar_popup(id);
+}
+
+YAHOO.crud.make_calendar_popup = function(id, set_time) {
+
+    var Dom = YAHOO.util.Dom;
+
+    // Create an Overlay instance to house the Calendar instance
+    var oCalendarMenu = new YAHOO.widget.Overlay("calendar_for_" + id);
+    
+    /*
+         Create an empty body element for the Overlay instance in order 
+         to reserve space to render the Calendar instance into.
+    */
+    oCalendarMenu.setBody("&#32;");
+    oCalendarMenu.body.id = "calendarcontainer_" + id;
+
+    // Render the Overlay instance into the Button's parent element
+    oCalendarMenu.render(Dom.get(id + "_calendar_container"));
+    
+
+    // Align the Overlay
+    oCalendarMenu.align();
+    
+    /*
+         Create a Calendar instance and render it into the body 
+         element of the Overlay.
+    */
+
+    var oCalendar = new YAHOO.widget.Calendar(
+        "buttoncalendar_" + id, 
+        oCalendarMenu.body.id,
+        {
+            close: true
+        });
+    oCalendar.render();
+    
+    
+    /* 
+        we have a close button but we want to hide the Overlay,
+        not the calendar
+    */
+    oCalendar.beforeHideEvent.subscribe(function() {
+        oCalendarMenu.hide();
+        return false;   // prevent calendar from being hidden
+    });
+
+    /* 
+        Subscribe to the Calendar instance's "changePage" event to 
+        keep the Overlay visible when either the previous or next page
+        controls are clicked.
+    */
+    oCalendar.changePageEvent.subscribe(function () {
+        window.setTimeout(function () {
+            oCalendarMenu.show();
+        }, 0);
+    });
+
+    /*
+        Subscribe to the Calendar instance's "select" event to 
+        update the form field when the user
+        selects a date.
+    */
+
+    oCalendar.selectEvent.subscribe(function (p_sType, p_aArgs) {
+
+        var aDate;
+        if (p_aArgs) {
+                
+            YAHOO.crud.log(p_aArgs);
+                
+            aDate = p_aArgs[0][0];
+            if (aDate[1] < 10)
+                aDate[1] = '0' + aDate[1];
+            
+            if (aDate[2] < 10)
+                aDate[2] = '0' + aDate[2];
+                
+            Dom.get(id).value = aDate.join('-');
+            if (set_time) {
+                Dom.get(id).value += ' 00:00:00';
+            }
+
+        }
+        
+        // hide calendar once date selected
+        oCalendarMenu.hide();
+    
+    });
+
+}
